<?php

App::uses('OrderBuilderInterface', 'EvCheckout.Lib');
App::uses('OrderBuilder', 'EvCheckout.Lib');

class BasketBuilder extends OrderBuilder implements OrderBuilderInterface {

	/**
	 * build an order from a basket
	 *
	 * @param 	int 	$transactionId 		The successful transaction ID just completed
	 * @return  int 	$orderId 			The id number of the order we just created
	 */
	public function build() {
		if (! CakePlugin::loaded('EvBasket')) {
			$this->_controller->Flash->fail('EvBasket is not loaded. Cannot process basket');
			return false;
		}

		if (! CakePlugin::loaded('EvAddressBook')) {
			$this->_controller->Flash->fail('EvAddressBook is not loaded. Cannot retrieve addresses');
			return false;
		}

		// load the address manager component
		if (empty($this->_controller->AddressManager)) {
			$this->_controller->AddressManager = $this->_controller->loadComponent('EvAddressBook.AddressManager');
		}

		// load the mbasket manager so we can get the basket
		if (empty($this->_controller->BasketManager)) {
			$this->_controller->BasketManager = $this->_controller->loadComponent('EvBasket.Basket');
		}

		// load the order manager component
		if (empty($this->_controller->OrderManager)) {
			$this->_controller->OrderManager = $this->_controller->loadComponent('EvCheckout.OrderManager');
		}

		// find the addresses to save to the order
		$addresses = $this->_controller->AddressManager->findAddresses();

		// format the addresses
		App::uses('AddressBookLib', 'EvAddressBook.Lib');

		foreach ($addresses as $key => $address) {
			$addresses[$key] = AddressBookLib::display($address);
		}

		$orderId = $this->_controller->OrderManager->createFromBasket(
			$this->_controller->BasketManager->getBasket(),
			$this->_controller->Auth->user('User'),
			$addresses
		);

		debug($orderId);
		die();
		return true;
	}

}
